@@ -158,6 +158,7 @@ class Universe:
         self._description = None
         self._bases = None
         self._dependencies = None
+        self._definition: Union[bytes, None] = None
 
         self._models = dict()
         self._endpoints = dict()
@@ -190,6 +191,10 @@ class Universe:
     def endpoints(self) -> List[any]:
         return list(self._endpoints.values())
 
+    @property
+    def definition(self) -> Union[bytes, None]:
+        return self._definition
+
     def get_pipe(self, name) -> Union[any, None]:
         return self._endpoints.get(name)
 
@@ -354,6 +359,7 @@ def load_universe(universe_def: Union[bytes, str]) -> Union[Universe, None]:
     universe._description = def_struct['description']
     universe._bases = def_struct['bases']
     universe._dependencies = def_struct['dependencies']
+    universe._definition = universe_def
 
     for object_def in def_struct['objects']:
         universe._add_model_def(object_def)
